

set -ex



$PREFIX/bin/addr2line --help
$PREFIX/bin/ar --help
$PREFIX/bin/as --help
$PREFIX/bin/c++filt --help
$PREFIX/bin/elfedit --help
$PREFIX/bin/gold --help
$PREFIX/bin/gprof --help
$PREFIX/bin/ld --help
$PREFIX/bin/ld.bfd --help
$PREFIX/bin/ld.gold --help
$PREFIX/bin/nm --help
$PREFIX/bin/objcopy --help
$PREFIX/bin/objdump --help
$PREFIX/bin/ranlib --help
$PREFIX/bin/readelf --help
$PREFIX/bin/size --help
$PREFIX/bin/strings --help
$PREFIX/bin/strip --help
exit 0
